@@ -1,5 +1,5 @@
 """
-Version 0.1.0 (in development)
+Version 0.2.1 (in development)
 ==============================
 
 A Python implementation of the Unity Engine
@@ -17,14 +17,14 @@ so:
 Debug information is turned on by default. If
 you want to turn it off, set the
 PYUNITY_DEBUG_MODE environment variable to ``"0"``.
-This is the output with debugging:
+This is the output with debugging::
 
     Loaded config
     Trying FreeGLUT as a window provider
     FreeGLUT doesn't work, trying GLFW
     GLFW doesn't work, trying Pygame
     Using window provider Pygame
-    Loaded PyUnity version 0.1.0
+    Loaded PyUnity version 0.2.1
 
 If debugging is off, there is no output:
 
@@ -35,10 +35,8 @@ If debugging is off, there is no output:
 
 Scenes
 ------
-All PyUnity projects start with a scene. There
-is no way to change between scenes yet.
-
-To add a scene, do this:
+All PyUnity projects start with a scene. To add
+a scene, do this:
 
     >>> scene = SceneManager.AddScene("Scene 1")
 
@@ -87,9 +85,9 @@ Pygame is tested last.
 To create your own provider, create a
 class that has the following methods:
 
-- `__init__`: initiate your window and
+- ``__init__``: initiate your window and
   check to see if it works.
-- `start`: start the main loop in your
+- ``start``: start the main loop in your
   window. The first parameter is
   ``update_func``, which is called
   when you want to do the OpenGL calls.
@@ -109,7 +107,7 @@ To run an example, import it like so:
     FreeGLUT doesn't work, trying GLFW
     GLFW doesn't work, trying Pygame
     Using window provider Pygame
-    Loaded PyUnity version 0.1.0
+    Loaded PyUnity version 0.2.1
     >>> main()
 
 Or from the command line:
@@ -117,14 +115,23 @@ Or from the command line:
     > python -m pyunity 1
 
 The ``1`` just means to load example 1, and there
-are 6 examples. To load all examples one by
+are 8 examples. To load all examples one by
 one, do not specify a number. If you want to
 contribute an example, then please create a
 new pull request.
 
 """
 
+__version__ = "0.2.1"
+__copyright__ = "Copyright 2020 Ray Chen"
+__email__ = "tankimarshal2@gmail.com"
+__license__ = "MIT License"
+__summary__ = "A Python implementation of the Unity Engine that supports different types of windows."
+__title__ = "pyunity"
+__uri__ = "https://pyunity.readthedocs.io/en/latest/"
+
 import os
+from .audio import *
 from .core import *
 from .vector3 import *
 from .quaternion import *
@@ -144,16 +151,8 @@ def timer(func):
         print(round(time() - start, 3))
     return wrapper
 
-__version__ = "0.1.0"
-__copyright__ = "Copyright 2020 Ray Chen"
-__email__ = "tankimarshal2@gmail.com"
-__license__ = "MIT License"
-__summary__ = "A Python implementation of the Unity Engine that supports different types of windows."
-__title__ = "pyunity"
-__uri__ = "https://pyunity.readthedocs.io/en/latest/"
-
 if os.environ["PYUNITY_DEBUG_MODE"] == "1":
-    print(f"Loaded PyUnity version {__version__}")
+    print("Loaded PyUnity version %s" % __version__)
 
 if os.environ["PYUNITY_INTERACTIVE"] == "1": del window, gl
 del core, scene, math, errors, operator, vector3, quaternion, physics, os
\ No newline at end of file
