@@ -20,7 +20,7 @@ def main():
     scene.Add(cube)
     
     scene.List()
-    scene.Run()
+    SceneManager.LoadScene(scene)
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
